@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package Email::Simple;
 # ABSTRACT: simple parsing of RFC2822 message format and headers
-$Email::Simple::VERSION = '2.209'; # TRIAL
+$Email::Simple::VERSION = '2.212'; # TRIAL
 use Carp ();
 
 use Email::Simple::Creator;
@@ -76,7 +76,7 @@ sub new {
 
   Carp::croak 'Unable to parse undefined message' if ! defined $text;
 
-  my $text_ref = ref $text ? $text : \$text;
+  my $text_ref = (ref $text || '' eq 'SCALAR') ? $text : \$text;
 
   my ($pos, $mycrlf) = $class->_split_head_from_body($text_ref);
 
@@ -214,9 +214,12 @@ sub header_obj_set {
 #pod
 #pod   my @values = $email->header($header_name);
 #pod   my $first  = $email->header($header_name);
+#pod   my $value  = $email->header($header_name, $index);
 #pod
 #pod In list context, this returns every value for the named header.  In scalar
-#pod context, it returns the I<first> value for the named header.
+#pod context, it returns the I<first> value for the named header.  If second
+#pod parameter is specified then instead I<first> value it returns value at
+#pod position C<$index> (negative C<$index> is from the end).
 #pod
 #pod =method header_set
 #pod
@@ -337,7 +340,7 @@ Email::Simple - simple parsing of RFC2822 message format and headers
 
 =head1 VERSION
 
-version 2.209
+version 2.212
 
 =head1 SYNOPSIS
 
@@ -428,9 +431,12 @@ header object.
 
   my @values = $email->header($header_name);
   my $first  = $email->header($header_name);
+  my $value  = $email->header($header_name, $index);
 
 In list context, this returns every value for the named header.  In scalar
-context, it returns the I<first> value for the named header.
+context, it returns the I<first> value for the named header.  If second
+parameter is specified then instead I<first> value it returns value at
+position C<$index> (negative C<$index> is from the end).
 
 =head2 header_set
 
@@ -498,9 +504,7 @@ for subclassing.  The default default is Email::Simple::Header.
 Email::Simple handles only RFC2822 formatted messages.  This means you cannot
 expect it to cope well as the only parser between you and the outside world,
 say for example when writing a mail filter for invocation from a .forward file
-(for this we recommend you use L<Email::Filter> anyway).  For more information
-on this issue please consult RT issue 2478,
-L<http://rt.cpan.org/NoAuth/Bug.html?id=2478>.
+(for this we recommend you use L<Email::Filter> anyway).
 
 =head1 AUTHORS
 
@@ -522,7 +526,7 @@ Ricardo SIGNES
 
 =head1 CONTRIBUTORS
 
-=for stopwords Brian Cassidy Christian Walde Michael Stevens Ricardo SIGNES Signes Ronald F. Guilmette William Yardley
+=for stopwords Brian Cassidy Christian Walde Michael Stevens Pali Ricardo SIGNES Ronald F. Guilmette William Yardley
 
 =over 4
 
@@ -540,11 +544,11 @@ Michael Stevens <mstevens@etla.org>
 
 =item *
 
-Ricardo SIGNES <rjbs@cpan.org>
+Pali <pali@cpan.org>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =item *
 
@@ -572,8 +576,6 @@ __END__
 #pod Email::Simple handles only RFC2822 formatted messages.  This means you cannot
 #pod expect it to cope well as the only parser between you and the outside world,
 #pod say for example when writing a mail filter for invocation from a .forward file
-#pod (for this we recommend you use L<Email::Filter> anyway).  For more information
-#pod on this issue please consult RT issue 2478,
-#pod L<http://rt.cpan.org/NoAuth/Bug.html?id=2478>.
+#pod (for this we recommend you use L<Email::Filter> anyway).
 #pod
 #pod =cut
