@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Email::Simple::Header;
 # ABSTRACT: the header of an Email::Simple message
-$Email::Simple::Header::VERSION = '2.209'; # TRIAL
+$Email::Simple::Header::VERSION = '2.212'; # TRIAL
 use Carp ();
 
 require Email::Simple;
@@ -136,7 +136,7 @@ sub header_names {
 
   my %seen;
   grep  { !$seen{ lc $_ }++ }
-    map { $headers->[ $_ * 2 ] } 0 .. int($#$headers / 2);
+    map { $headers->[ $_ * 2 ] } 0 .. @$headers / 2 - 1;
 }
 
 #pod =method header_raw_pairs
@@ -175,6 +175,7 @@ sub header_pairs {
 #pod =method header_raw
 #pod
 #pod   my $first_value = $header->header_raw($field);
+#pod   my $nth_value   = $header->header_raw($field, $index);
 #pod   my @all_values  = $header->header_raw($field);
 #pod
 #pod This method returns the value or values of the given header field.  If the
@@ -191,19 +192,24 @@ sub header_pairs {
 sub _str_value { return ref $_[0] ? $_[0][0] : $_[0] }
 
 sub header_raw {
-  my ($self, $field) = @_;
+  my ($self, $field, $index) = @_;
 
   my $headers  = $self->{headers};
   my $lc_field = lc $field;
 
-  if (wantarray) {
+  if (wantarray and not defined $index) {
     return map { _str_value($headers->[ $_ * 2 + 1 ]) }
-      grep { lc $headers->[ $_ * 2 ] eq $lc_field } 0 .. int($#$headers / 2);
+      grep { lc $headers->[ $_ * 2 ] eq $lc_field } 0 .. @$headers / 2 - 1;
   } else {
-    for (0 .. int($#$headers / 2)) {
-      return _str_value($headers->[ $_ * 2 + 1 ]) if lc $headers->[ $_ * 2 ] eq $lc_field;
+    $index = 0 unless defined $index;
+    my $max = @$headers / 2 - 1;
+    my @indexes = $index >= 0 ? (0 .. $max) : reverse(0 .. $max);
+    $index = -1-$index if $index < 0;
+    for (@indexes) {
+      next unless lc $headers->[ $_ * 2 ] eq $lc_field;
+      return _str_value($headers->[ $_ * 2 + 1 ]) if $index-- == 0;
     }
-    return;
+    return undef;
   }
 }
 
@@ -251,7 +257,7 @@ sub header_raw_set {
 
   my $lc_field = lc $field;
   my @indices = grep { lc $headers->[$_] eq $lc_field }
-    map { $_ * 2 } 0 .. int($#$headers / 2);
+    map { $_ * 2 } 0 .. @$headers / 2 - 1;
 
   if (@indices > @data) {
     my $overage = @indices - @data;
@@ -324,10 +330,10 @@ sub __fold_objless {
 
   # We know it will not contain any new lines at present
   my $folded = "";
-  while ($line) {
+  while (length $line) {
     if ($line =~ s/^(.{0,$limit})(\s|\z)//) {
       $folded .= $1 . $crlf;
-      $folded .= $indent if $line;
+      $folded .= $indent if length $line;
     } else {
       # Basically nothing we can do. :(
       $folded .= $line . $crlf;
@@ -370,7 +376,7 @@ Email::Simple::Header - the header of an Email::Simple message
 
 =head1 VERSION
 
-version 2.209
+version 2.212
 
 =head1 SYNOPSIS
 
@@ -429,6 +435,7 @@ you.)
 =head2 header_raw
 
   my $first_value = $header->header_raw($field);
+  my $nth_value   = $header->header_raw($field, $index);
   my @all_values  = $header->header_raw($field);
 
 This method returns the value or values of the given header field.  If the
